Test coverage report: calendarium.tests.test_app.models

# calendarium.tests.test_app.models: 7 total statements, 100.0% covered

Generated: Sun 2013-03-24 21:11 CET

Source file: /home/tobi/Projects/calendarium/src/calendarium/tests/test_app/models.py

Stats: 5 executed, 0 missed, 2 excluded, 16 ignored

1. `"""Models for the ``test_app`` test app."""`
2. `import factory`
3. ``
4. `from django.db import models`
5. ``
6. ``
7. `class DummyModel(models.Model):`
8. `"""`
9. `This is a dummy model for testing purposes.`
10. ``
11. `:content: Just a dummy field.`
12. ``
13. `"""`
14. `content = models.CharField(`
15. `max_length=32,`
16. `)`
17. ``
18. ``
19. `class DummyModelFactory(factory.Factory):`
20. `"""Factory for the ``DummyModel`` model."""`
21. `FACTORY_FOR = DummyModel`
22. ``
23. `content = factory.Sequence(lambda n: 'content{0}'.format(n))`